@@ -7,7 +7,7 @@
 
 #include "blankanswer.h"
 #include "kwqsortfiltermodel.h"
-#include "kwqtablemodel.h"
+#include "kwqcardmodel.h"
 
 #include <QRandomGenerator>
 
@@ -15,7 +15,7 @@
 
 KWQQuizModel::KWQQuizModel(QObject *parent) : QSortFilterProxyModel(parent)
 {
-    m_sourceModel = 0;
+    m_sourceModel = nullptr;
     m_currentQuestion = 0;
     setSortCaseSensitivity(Qt::CaseInsensitive);
     setFilterCaseSensitivity(Qt::CaseInsensitive);
@@ -83,7 +83,7 @@ bool KWQQuizModel::hasErrors()
 
 bool KWQQuizModel::init()
 {
-    if (m_sourceModel == 0)
+    if (m_sourceModel == nullptr)
         return false;
 
     invalidate();
@@ -167,26 +167,21 @@ bool KWQQuizModel::checkAnswer(const QString & a)
                     break;
                 }
             }
-        }
-        else
-        {
-          result = (ans == tTemp);
-        }
-      }
-      else
-      {
-        if (m_quizType == Prefs::EnumStartSession::MultipleChoice) {
-            if (Prefs::enableBlanks()) {
-                tTemp.remove('[');
-                tTemp.remove(']');
-            }
+        } else if (Prefs::caseSensitiveAnswers()) {
             result = (ans == tTemp);
+        } else {
+            result = ans.compare(tTemp, Qt::CaseInsensitive) == 0;
         }
-        else
-        {
-          result = (ans == tTemp);
-        }
-
+      } else {
+          if (m_quizType == Prefs::EnumStartSession::MultipleChoice) {
+              if (Prefs::enableBlanks()) {
+                  tTemp.remove('[');
+                  tTemp.remove(']');
+              }
+              result = (ans == tTemp);
+          } else {
+            result = (ans == tTemp);
+          }
       }
       ///@todo currently the Leitner stuff crashes KWQ
       //QString tmpLeitner( m_doc->entry(li.oneOp())->leitnerBox() );
@@ -336,63 +331,6 @@ QString KWQQuizModel::answer()
     return s;
 }
 
-
-QUrl KWQQuizModel::soundQuestion()
-{
-    int row =  m_list.at(m_currentQuestion);
-    int col = column(row);
-    col == 0 ? col = 1 : col = 0;
- 
-    QUrl soundUrl = QUrl::fromLocalFile(data(index(qAbs(row), col, QModelIndex()), KWQTableModel::SoundRole).toString());
-    return soundUrl;
-}
- 
-
-QUrl KWQQuizModel::soundAnswer()
-{
-    int row =  m_list.at(m_currentQuestion);
-    QUrl soundUrl = QUrl::fromLocalFile(data(index(qAbs(row), column(row), QModelIndex()), KWQTableModel::SoundRole).toString());
-    return soundUrl;
-}
-
-
-QPixmap KWQQuizModel::imageQuestion()
-{
-    int row =  m_list.at(m_currentQuestion);
-    int col = column(row);
-    col == 0 ? col = 1 : col = 0;
-
-    QUrl imageUrl = QUrl::fromLocalFile(data(index(qAbs(row), col, QModelIndex()), KWQTableModel::ImageRole).toString());
-    return QPixmap(imageUrl.toLocalFile());
-}
-
-
-QPixmap KWQQuizModel::imageAnswer()
-{
-    int row =  m_list.at(m_currentQuestion);
-    QUrl imageUrl = QUrl::fromLocalFile(data(index(qAbs(row), column(row), QModelIndex()), KWQTableModel::ImageRole).toString());
-    return QPixmap(imageUrl.toLocalFile());
-}
-
-
-QString KWQQuizModel::langQuestion()
-{
-    if (column(m_list.at(m_currentQuestion)) == 1)
-        return headerData(0, Qt::Horizontal, Qt::DisplayRole).toString();
-    else
-        return headerData(1, Qt::Horizontal, Qt::DisplayRole).toString();
-}
-
-
-QString KWQQuizModel::langAnswer()
-{
-    if (column(m_list.at(m_currentQuestion)) == 0)
-        return headerData(0, Qt::Horizontal, Qt::DisplayRole).toString();
-    else
-        return headerData(1, Qt::Horizontal, Qt::DisplayRole).toString();
-}
-
-
 QString KWQQuizModel::kbAnswer()
 {
     int col = column(m_list.at(m_currentQuestion));
@@ -449,3 +387,5 @@ void KWQQuizModel::activateErrorList()
 }
 
 inline bool KWQQuizModel::isOdd(int value) const { return value & 0x1; }
+
+#include "moc_kwqquizmodel.cpp"
